@@ -1,5 +1,6 @@
-class User():
+class User:
     """Public class for User model."""
+
     id: int = 0
     inat_user_id: int = None
     inat_place_id: int = None
